@@ -255,7 +255,7 @@ class Client:
         pipelines: Union[str, List[str]] = ["transcribe", "summarize"],  # noqa: B006
         source_lang: Optional[str] = None,
         split_long_utterances: Optional[bool] = False,
-        summary_length: Optional[Union[int, List[int]]] = None,
+        summary_lens: Optional[Union[int, List[int]]] = None,
         tags: Optional[Union[str, List[str]]] = None,
     ) -> SummarizeJob:
         """Start a Summary job."""
@@ -265,20 +265,20 @@ class Client:
             )
 
         if summary_type == "reason_conclusion":
-            if summary_length:
+            if summary_lens:
                 logger.warning(
                     """
                     You have specified a summary length for a reason_conclusion summary but reason_conclusion summaries
-                    do not use a summary length. The summary_length parameter will be ignored.
+                    do not use a summary length. The summary_lens parameter will be ignored.
                 """
                 )
         else:
-            if summary_length is None:
+            if summary_lens is None:
                 logger.warning(
                     "You have not specified a summary length. Defaulting to 3."
                 )
-                summary_length = 3
-            if _check_summary_length(summary_length) is False:
+                summary_lens = 3
+            if _check_summary_length(summary_lens) is False:
                 raise ValueError(
                     f"""
                     You must specify a valid summary length. Summary length must be an integer or a list of integers.
@@ -359,8 +359,8 @@ class Client:
             "split_long_utterances": str(split_long_utterances).lower(),
             "summary_type": summary_type,
         }
-        if summary_type != "reason_conclusion" and summary_length:
-            params["summary_lens"] = _format_lengths(summary_length)
+        if summary_type != "reason_conclusion" and summary_lens:
+            params["summary_lens"] = _format_lengths(summary_lens)
         if tags:
             params["tags"] = _format_tags(tags)
 
