@@ -70,8 +70,10 @@ class BaseSummary:
     process_time: Optional[str] = field(default=None)
     speaker_map: Optional[Dict[str, str]] = field(default=None)
     source: Optional[str] = field(default=None)
+    source_lang: Optional[str] = field(default=None)
     summary_type: Optional[str] = field(default=None)
     summary: Optional[Dict[str, Any]] = field(default=None)
+    target_lang: Optional[str] = field(default=None)
     transcript_id: Optional[str] = field(default=None)
     time_started: Optional[str] = field(default=None)
     time_completed: Optional[str] = field(default=None)
